# Copyright 2003-2004 Jochen Eisinger
# Distributed under the terms of the GNU General Public License v2

inherit kmod eutils

KMOD_SOURCES="${PN}-linux-${PV}.tar.gz"
DESCRIPTION="Application Panel driver for Fujitsu Siemens Lifebooks"
HOMEPAGE="http://apanel.sourceforge.net/"
SRC_URI="mirror://sourceforge/${PN}/${PN}-linux-${PV}.tar.gz"

LICENSE="GPL-2"
SLOT="0"
KEYWORDS="x86 -ppc -sparc -alpha"

DEPEND="virtual/linux-sources
	sys-kernel/config-kernel"

src_unpack() {
  kmod_src_unpack
  cd ${WORKDIR}/${PN}-linux-${PV}
  if is_kernel 2 6
  then
    mv -f linux/Makefile-2.6 linux/Makefile
  fi
  epatch ${FILESDIR}/apanel.c.diff
}

src_compile() {
  kmod_make_linux_writable
  cd ${WORKDIR}/${PN}-linux-${PV}
  if is_kernel 2 6
  then
    ( cd linux; kmod_src_compile || die "failed to compile kernel module" )
  else
    make -C linux I2C=/usr/include || die "failed to compile kernel module"
  fi
  make -C utils || die "failed to compile tools"
}

src_install() {
  kmod_make_linux_writable

  cd ${WORKDIR}/${PN}-linux-${PV}
  dodoc COPYING README.linux README.utils CREDITS

  insinto ${ROOT}/lib/modules/${KV}/misc
  doins linux/apanel.$KV_OBJ

  exeinto "/etc/init.d"
  doexe "${FILESDIR}"/apanel

  insinto "/etc/modules.d"
  newins "${FILESDIR}"/apanel.modules apanel

  insinto "/etc/devfs.d"
  newins "${FILESDIR}"/apanel.devfs apanel

  insinto "/etc/udev/rules.d"
  newins "${FILESDIR}"/apanel.udev 99-apanel.rules

  dosbin utils/fjkeyd
  dobin  utils/apanelc

  keepdir "/etc/apanel"
}

pkg_postinst() {
  if [ "$ROOT" = "/" ]
  then
	[ -x /usr/sbin/update-modules ] && /usr/sbin/update-modules
  fi
}
